@@ -3,7 +3,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     let root =
         BitMapBackend::new("plotters-doc-data/histogram.png", (640, 480)).into_drawing_area();
 
-    root.fill(&White)?;
+    root.fill(&WHITE)?;
 
     let mut chart = ChartBuilder::on(&root)
         .x_label_area_size(35)
@@ -15,7 +15,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     chart
         .configure_mesh()
         .disable_x_mesh()
-        .line_style_1(&White.mix(0.3))
+        .line_style_1(&WHITE.mix(0.3))
         .x_label_offset(30)
         .y_desc("Count")
         .x_desc("Bucket")
@@ -28,7 +28,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 
     chart.draw_series(
         Histogram::vertical(&chart)
-            .style(Red.mix(0.5).filled())
+            .style(RED.mix(0.5).filled())
             .data(data.iter().map(|x: &u32| (*x, 1))),
     )?;
 
